@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 import json
-from typing import Optional, Iterable
+from typing import Optional, Iterator, Any
 
 from psnawp_api.core.psnawp_exceptions import (
     PSNAWPNotFound,
@@ -14,30 +14,30 @@ from psnawp_api.utils.request_builder import RequestBuilder
 
 
 class Group:
+    """The Group class is responsible for providing convenient methods to interact with PSN group endpoints, responsible for managing messages groups and sending messages."""
+
     def __init__(
         self,
         request_builder: RequestBuilder,
         group_id: Optional[str],
-        users: Optional[Iterable[User]],
+        users: Optional[Iterator[User]],
     ):
-        """Constructor of Group. Responsible for managing messages groups and sending messages.
+        """Constructor of Group.
 
         .. note::
 
             This class is intended to be interfaced with through PSNAWP.
 
-        :param request_builder: The instance of RequestBuilder. Used to make
-            HTTPRequests.
+        :param request_builder: The instance of RequestBuilder. Used to make HTTPRequests.
         :type request_builder: RequestBuilder
         :param group_id: The Group ID of a group.
         :type group_id: Optional[str]
         :param users: A list of users of the members in the group.
-        :type users: Optional[Iterable[User]]
+        :type users: Optional[Iterator[User]]
 
         :raises: ``PSNAWPNotFound`` If group id does not exist or is invalid.
 
-        :raises: ``PSNAWPForbidden`` If you are Dming a user who has blocked you.
-            blocked you.
+        :raises: ``PSNAWPForbidden`` If you are Dming a user who has blocked you. blocked you.
 
         """
 
@@ -50,7 +50,7 @@ class Group:
         elif self.users is not None:
             self._create_group()
 
-    def _create_group(self):
+    def _create_group(self) -> None:
         """Creates a new group if it doesn't exist. Doesn't work if user's privacy settings block invites.
 
         :raises: ``PSNAWPForbidden`` If you are Dming a user who has blocked you.
@@ -67,17 +67,14 @@ class Group:
                 ).json()
                 self.group_id = response["groupId"]
             except PSNAWPForbidden as forbidden:
-                raise PSNAWPForbidden(
-                    "The group cannot be created because you have been blocked by other user."
-                ) from forbidden
+                raise PSNAWPForbidden("The group cannot be created because the user has either set messages to private or has blocked you.") from forbidden
 
     def change_name(self, group_name: str) -> None:
         """Changes the group name to one specified in arguments.
 
         .. note::
 
-            You cannot change the name of DM groups. i.e. Groups with only two people
-            (including you).
+            You cannot change the name of DM groups. i.e. Groups with only two people (including you).
 
         :param group_name: The name of the group that will be set.
         :type group_name: str
@@ -95,11 +92,9 @@ class Group:
                 data=json.dumps(data),
             )
         except PSNAWPBadRequest as bad_req:
-            raise PSNAWPBadRequest(
-                f"The group name of Group ID {self.group_id} does cannot be changed. Group is either a dm or does not exist."
-            ) from bad_req
+            raise PSNAWPBadRequest(f"The group name of Group ID {self.group_id} does cannot be changed. Group is either a dm or does not exist.") from bad_req
 
-    def get_group_information(self):
+    def get_group_information(self) -> dict[str, Any]:
         """Gets the group chat information such as about me, avatars, languages etc...
 
         :returns: A dict containing info similar to what is shown below:
@@ -163,16 +158,14 @@ class Group:
         }
 
         try:
-            response = self._request_builder.get(
+            response: dict[str, Any] = self._request_builder.get(
                 url=f"{BASE_PATH['gaming_lounge']}{API_PATH['group_members'].format(group_id=self.group_id)}",
                 params=param,
             ).json()
 
             return response
         except PSNAWPNotFound as not_found:
-            raise PSNAWPNotFound(
-                f"Group ID {self.group_id} does not exist."
-            ) from not_found
+            raise PSNAWPNotFound(f"Group ID {self.group_id} does not exist.") from not_found
 
     def send_message(self, message: str) -> dict[str, str]:
         """Sends a message in the group.
@@ -204,7 +197,7 @@ class Group:
 
         return response
 
-    def get_conversation(self, limit: int = 20):
+    def get_conversation(self, limit: int = 20) -> dict[str, Any]:
         """Gets the conversations in a group.
 
         :param limit: The number of conversations to receive.
@@ -239,7 +232,7 @@ class Group:
 
         param = {"limit": limit}
 
-        response = self._request_builder.get(
+        response: dict[str, Any] = self._request_builder.get(
             url=f"{BASE_PATH['gaming_lounge']}{API_PATH['conversation'].format(group_id=self.group_id)}",
             params=param,
         ).json()
@@ -253,6 +246,10 @@ class Group:
 
         """
 
-        self._request_builder.delete(
-            url=f"{BASE_PATH['gaming_lounge']}{API_PATH['leave_group'].format(group_id=self.group_id)}"
-        )
+        self._request_builder.delete(url=f"{BASE_PATH['gaming_lounge']}{API_PATH['leave_group'].format(group_id=self.group_id)}")
+
+    def __repr__(self) -> str:
+        return f"<Group group_id:{self.group_id}>"
+
+    def __str__(self) -> str:
+        return f"Group ID: {self.group_id}"
